#include "kineticpopuphandler.h"


KineticPopupHandler::KineticPopupHandler()
{
        FAvatars = NULL;
        FNotifications = NULL;
        FNotify = NULL;
}

KineticPopupHandler::~KineticPopupHandler()
{
        delete FNotify;
}

void KineticPopupHandler::pluginInfo(IPluginInfo *APluginInfo)
{
        APluginInfo->name = tr("Kinetic Popup Notifications Handler");
        APluginInfo->description = tr("Allows other modules use nice Kinetic popup");
        APluginInfo->version = "1.0."SVN_REVISION;
        APluginInfo->author = "Crying Angel";
        APluginInfo->homePage = "http://code.google.com/p/vacuum-plugins";
        APluginInfo->dependences.append(NOTIFICATIONS_UUID);
        APluginInfo->dependences.append(AVATARTS_UUID);
}

bool KineticPopupHandler::initConnections(IPluginManager *APluginManager, int &/*AInitOrder*/)
{
        IPlugin *plugin;

	plugin = APluginManager->pluginInterface("IAvatars").value(0,NULL);
        if (!plugin) return false;
		FAvatars = qobject_cast<IAvatars *>(plugin->instance());

        plugin = APluginManager->pluginInterface("INotifications").value(0,NULL);
        if (!plugin) return false;
                FNotifications = qobject_cast<INotifications *>(plugin->instance());

        connect (APluginManager->instance(), SIGNAL(aboutToQuit()), this, SLOT(onApplicationQuit()));

	return true;
}

bool KineticPopupHandler::initObjects()
{
        FNotifications->insertNotificationHandler(NHO_KIPOPUP, this);

	return true;
}

bool KineticPopupHandler::initSettings()
{
        FTimeout = 6000;
	return true;
}

bool KineticPopupHandler::showNotification(int AOrder, ushort AKind, int ANotifyId, const INotification &ANotification)
{
    if (AOrder!=NHO_KIPOPUP||!(AKind&INotification::PopupWindow)) return false;

    Jid contactJid = ANotification.data.value(NDR_CONTACT_JID).toString();
    QString toolTip = ANotification.data.value(NDR_TOOLTIP).toString();
    QString imgPath;

    FTimeout = Options::node(OPV_NOTIFICATIONS_POPUPTIMEOUT).value().toInt()*1000;

    if (FAvatars)
    {
        imgPath = FAvatars->avatarFileName(FAvatars->avatarHash(contactJid));
    }

    FNotify = new KineticNotification(QString::number(ANotifyId),FTimeout);

    if (imgPath.isEmpty()) imgPath = ":/kinotify/resources/images/kinotify.svg";
    FNotify->setMessage(ANotification.data.value(NDR_POPUP_CAPTION).toString(),
                        toolTip+"<br>"+ANotification.data.value(NDR_POPUP_HTML).toString(),
                        imgPath);
    FNotify->send();
    connect(FNotify, SIGNAL(action1Activated()), this, SLOT(onWindowNotifyActivated()));
    connect(FNotify, SIGNAL(action2Activated()), this, SLOT(onWindowNotifyRemoved()));

    return true;
}

void KineticPopupHandler::onWindowNotifyActivated()
{
        KineticNotification* notify = qobject_cast<KineticNotification*>(sender());
        FNotifications->activateNotification(notify->getId().toInt());
}

void KineticPopupHandler::onWindowNotifyRemoved(/*int ANotifyId*/)
{
        KineticNotification* notify = qobject_cast<KineticNotification*>(sender());
        FNotifications->removeNotification(notify->getId().toInt());
}

void KineticPopupHandler::onApplicationQuit()
{
    FNotifications->removeNotificationHandler(NHO_KIPOPUP, this);
}

//void KineticPopupHandler::onWindowNotifyDestroyed()
//{

//}

Q_EXPORT_PLUGIN2(plg_notifications, KineticPopupHandler)
